LoadingScreenConfig class

Constructors

LoadingScreenConfig({Color backgroundColor = Colors.white, Color progressColor = const Color(0xFFDA291C), Color textColor = const Color(0xFF1E1E1E), String loadingText = 'Processing...', double logoSize = 40.0, TextStyle? textStyle, Widget? logoWidget, double progressIndicatorSize = 60.0})
const
LoadingScreenConfig.defaultConfig()
factory

Properties

backgroundColor Color
final
hashCode int
The hash code for this object.
no setterinherited
loadingText String
final
logoSize double
final
logoWidget Widget?
final
progressColor Color
final
progressIndicatorSize double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor Color
final
textStyle TextStyle?
final

Methods

copyWith({Color? backgroundColor, Color? progressColor, Color? textColor, String? loadingText, double? logoSize, TextStyle? textStyle, Widget? logoWidget, double? progressIndicatorSize}) LoadingScreenConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited