VerifiedResultScreenConfig class

Constructors

VerifiedResultScreenConfig({TextStyle? titleStyle, TextStyle? subtitleStyle, TextStyle? labelStyle, TextStyle? valueStyle, Color? primaryColor, Color? backgroundColor, Color? cardColor, Color? buttonColor, Color? buttonTextColor})
VerifiedResultScreenConfig.defaultConfig()
factory

Properties

backgroundColor Color?
final
buttonColor Color?
final
buttonTextColor Color?
final
cardColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
labelStyle TextStyle?
final
primaryColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitleStyle TextStyle?
final
titleStyle TextStyle?
final
valueStyle TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited