ErrorCodes class
Common error codes used throughout the SDK
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- apiError → const String
- apiTimeout → const String
- authenticationFailed → const String
- cameraPermissionDenied → const String
- documentNotRecognized → const String
- faceMatchFailed → const String
- faceNotDetected → const String
- initializationFailed → const String
- invalidConfiguration → const String
- invalidFieldValue → const String
- invalidLicense → const String
- invalidUrl → const String
- livenessFailed → const String
- missingConfiguration → const String
- missingRequiredField → const String
- multipleFacesDetected → const String
- networkError → const String
- poorImageQuality → const String
- scanCancelled → const String
- scanFailed → const String
- scanTimeout → const String