DocumentScanException class

Exception thrown when document scanning fails

This can occur when:

  • Document is not recognized
  • Image quality is too poor
  • User cancels the scan
  • Camera permission is denied
  • Timeout occurs during scanning
Inheritance

Constructors

DocumentScanException(String message, {String? code, dynamic originalError, StackTrace? stackTrace})
const

Properties

code String?
Optional error code for programmatic error handling
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message
finalinherited
originalError → dynamic
Original error that caused this exception (if any)
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
Stack trace from the original error (if available)
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited