ScreensConfig class
Consolidated configuration for all UI screens in the SDK
This class groups all screen-specific configurations together for easier management and discovery.
Example:
final screensConfig = ScreensConfig(
onboarding: OnboardingConfig(
buttonColor: Colors.blue,
),
loading: LoadingScreenConfig(
progressColor: Colors.blue,
),
);
Constructors
- ScreensConfig({OnboardingConfig? onboarding, LoadingScreenConfig? loading, VerifiedResultScreenConfig? result, RegisterScreenConfig? register})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- loading → LoadingScreenConfig?
-
Configuration for the loading screen
final
- onboarding → OnboardingConfig?
-
Configuration for the onboarding screen
final
- register → RegisterScreenConfig?
-
Configuration for the registration screen
final
- result → VerifiedResultScreenConfig?
-
Configuration for the verification result screen
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{OnboardingConfig? onboarding, LoadingScreenConfig? loading, VerifiedResultScreenConfig? result, RegisterScreenConfig? register}) → ScreensConfig - Creates a copy with optional parameter overrides
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited