CameraFrameConfig class

Constructors

CameraFrameConfig({bool show = true, int? lineWidth, Color? borderColor, double? cornerRadius, double? aspectRatio, double? portraitAspectRatio, double? landscapeAspectRatio, int? offsetWidth, int? borderWidth})

Properties

aspectRatio → double?
final
borderColor → Color?
final
borderWidth → int?
final
cornerRadius → double?
final
hashCode → int
The hash code for this object.
no setterinherited
landscapeAspectRatio → double?
final
lineWidth → int?
final
offsetWidth → int?
final
portraitAspectRatio → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
show → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited