ImageQualityConfig class

Constructors

ImageQualityConfig({int? dpiThreshold, int? angleThreshold, bool focusCheck = true, bool glaresCheck = true, bool colornessCheck = true})

Properties

angleThreshold → int?
final
colornessCheck → bool
final
dpiThreshold → int?
final
focusCheck → bool
final
glaresCheck → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited