InstructionsConfig class

Constructors

InstructionsConfig({bool showAnimation = true, double? animationDuration, double? animationDelay, String? animationText})

Properties

animationDelay → double?
final
animationDuration → double?
final
animationText → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showAnimation → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited