MessagesConfig class

Constructors

MessagesConfig({bool showStatus = true, bool showResultStatus = true, Font? statusTextFont, double? statusTextSize, Font? resultStatusTextFont, double? resultStatusTextSize, double? resultStatusTimeout, Map<String, String>? hintMessages})

Properties

hashCode int
The hash code for this object.
no setterinherited
hintMessages Map<String, String>?
final
resultStatusTextFont → Font?
final
resultStatusTextSize double?
final
resultStatusTimeout double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showResultStatus bool
final
showStatus bool
final
statusTextFont → Font?
final
statusTextSize double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited