MultipageConfig class

Constructors

MultipageConfig({bool enabled = false, bool showAnimation = true, String? buttonText, bool showButton = true, double? timeout, double? timeoutFromFirstDetect})

Properties

buttonText String?
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showAnimation bool
final
showButton bool
final
timeout double?
final
timeoutFromFirstDetect double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited