ProcessParamsConfig class

Constructors

ProcessParamsConfig({String? scenario, bool returnCroppedBarcode = true, bool returnCroppedImage = true, bool returnUncroppedImage = false, ImageQualityConfig? imageQuality, String? dateFormat, bool measureSystemPerformance = false, List<int>? documentIdList, bool multipageProcessing = false, bool alreadyCropped = false, bool generateNumericCodes = true})

Properties

alreadyCropped → bool
final
dateFormat → String?
final
documentIdList → List<int>?
final
generateNumericCodes → bool
final
hashCode → int
The hash code for this object.
no setterinherited
imageQuality → ImageQualityConfig?
final
measureSystemPerformance → bool
final
multipageProcessing → bool
final
returnCroppedBarcode → bool
final
returnCroppedImage → bool
final
returnUncroppedImage → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scenario → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited