RFIDConfig class

Constructors

RFIDConfig({bool showUI = true, String? hintText, String? progressText, String? successText, String? failureText, int? timeout})

Properties

failureText → String?
final
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
final
progressText → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showUI → bool
final
successText → String?
final
timeout → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited