DocReaderSdkSteps class

Constructors

DocReaderSdkSteps()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addFaceApi({required String faceApiUrl, required String mode}) → void
customizeCheck({bool preventScreenRecording = true, bool checkCaptureProcessIntegrity = true, bool useFaceApi = true, bool useAuthenticityCheck = true, bool useLivenessCheck = true, bool checkGeometry = false, bool checkHolo = true, bool checkED = true, bool checkBlackAndWhiteCopy = true}) → void
finalise() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recognize({required Uint8List? image, required String faceApiUrl, required void handleCompletion(DocReaderAction action, Results? result, DocReaderException? error)}) → void
scan({required String faceApiUrl, required String mode, required void handleCompletion(DocReaderAction action, Results? result, DocReaderException? error)}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited