ScanResult class

Constructors

ScanResult({required String name, String? firstName, String? lastName, required String passportNumber, required String nationality, required String? age, String? dateOfBirth, required Uint8List docImage, Uint8List? selfieImage, String? transactionId, String? faceLivenessTransactionId, Map<String, dynamic>? verificationStatus})

Properties

age → String?
final
dateOfBirth → String?
final
docImage → Uint8List
final
faceLivenessTransactionId → String?
final
firstName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
lastName → String?
final
name → String
final
nationality → String
final
passportNumber → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selfieImage → Uint8List?
final
transactionId → String?
final
verificationStatus → Map<String, dynamic>?
final

Methods

copyWith({String? name, String? firstName, String? lastName, String? passportNumber, String? nationality, Uint8List? docImage, String? age, String? dateOfBirth, Uint8List? selfieImage, String? transactionId, String? faceLivenessTransactionId, Map<String, dynamic>? verificationStatus}) → ScanResult
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited