FaceSDKConfig class

Main entry point for Face SDK configuration This class provides a fluent API to configure all customization options

Constructors

FaceSDKConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply() Future<void>
Apply all configurations to the Face SDK
applyRuntime() Future<void>
Apply changes in runtime
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() Future<void>
Reset all configurations to defaults
toString() String
A string representation of this object.
inherited
withColors(FaceColorsConfig config) FaceSDKConfig
Configure colors
withFonts(FaceFontsConfig config) FaceSDKConfig
Configure fonts
withImages(FaceImagesConfig config) FaceSDKConfig
Configure images

Operators

operator ==(Object other) bool
The equality operator.
inherited