FaceImagesConfig class

Configuration for Face SDK image customization

Constructors

FaceImagesConfig({ByteData? onboardingScreenIllumination, ByteData? onboardingScreenAccessories, ByteData? onboardingScreenCameraLevel, ByteData? successScreenImage, ByteData? retryScreenHintSubject, ByteData? retryScreenHintEnvironment})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
onboardingScreenAccessories → ByteData?
final
onboardingScreenCameraLevel → ByteData?
final
onboardingScreenIllumination → ByteData?
final
retryScreenHintEnvironment → ByteData?
final
retryScreenHintSubject → ByteData?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
successScreenImage → ByteData?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited