DeepLinkAction class
Constructors
-
DeepLinkAction({required DeepLinkType type, required Map<
String, String> params})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
params
→ Map<
String, String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → DeepLinkType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited