SDKConfigManager class

Properties

documentReaderConfig DocumentReaderConfig?
no setter
documentReaderUrl String
no setter
faceApiUrl String
no setter
faceSDKConfig FaceSDKConfig?
no setter
hashCode int
The hash code for this object.
no setterinherited
isInitialized bool
no setter
license ByteData
no setter
loadingScreenConfig LoadingScreenConfig
no setter
onboardingConfig OnboardingConfig
no setter
onReprocess Future<bool> Function(String, String?)?
no setter
registerConfig RegisterScreenConfig
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verifiedResultConfig VerifiedResultScreenConfig
no setter

Methods

initialize({VerifiedResultScreenConfig? verifiedResultConfig, RegisterScreenConfig? registerConfig, OnboardingConfig? onboardingConfig, LoadingScreenConfig? loadingScreenConfig, FaceSDKConfig? faceSDKConfig, DocumentReaderConfig? documentReaderConfig, required ByteData license, required String faceApiUrl, required String documentReaderUrl, Future<bool> onReprocess(String, String?)?}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance SDKConfigManager
no setter