FieldConfig class

Constructors

FieldConfig({required String key, required String label, TextInputType inputType = TextInputType.text, bool isRequired = true, int? maxLines = 1, String? hint, Widget? prefix, bool isDate = false, String? validationRegex, String? validationErrorMessage, String? matchKey, String? matchKeyError, String? validator(String?)?})

Properties

hashCode → int
The hash code for this object.
no setterinherited
hint → String?
final
inputType → TextInputType
final
isDate → bool
final
isRequired → bool
final
key → String
final
label → String
final
matchKey → String?
final
matchKeyError → String?
final
maxLines → int?
final
prefix → Widget?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validationErrorMessage → String?
final
validationRegex → String?
final
validator → String? Function(String?)?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited