FormConfig constructor

FormConfig({
  1. required NavigationType navigationType,
  2. required List<FieldConfig> fields,
  3. String title = "Create An Account",
  4. String subtitle = "Join now for free and be part of United's global fan community to enjoy exclusive perks & rewards",
  5. String buttonText = "Create Account",
  6. String? logoPath,
  7. bool showTerms = true,
})

Implementation

FormConfig({
  required this.navigationType,
  required this.fields,
  this.title = "Create An Account",
  this.subtitle =
      "Join now for free and be part of United's global fan community to enjoy exclusive perks & rewards",
  this.buttonText = "Create Account",
  this.logoPath,
  this.showTerms = true,
});