AdaptiveImage class

A widget that displays either a local asset image or a network image based on the provided path.

Inheritance

Constructors

AdaptiveImage({Key? key, required String imagePath, double? width, double? height, BoxFit fit = BoxFit.contain, BorderRadius? borderRadius, Widget? placeholder, Widget? errorWidget})
const

Properties

borderRadius BorderRadius?
Border radius for the image container
final
errorWidget Widget?
Error widget to show if image fails to load
final
fit BoxFit
Box fit for the image
final
hashCode int
The hash code for this object.
no setterinherited
height double?
Height of the image container
final
imagePath String
The image path - can be either:
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
placeholder Widget?
Placeholder widget to show while loading network images
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
Width of the image container
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited