CircularIconProgress class

A circular progress indicator with a customizable icon in the center

Inheritance

Constructors

CircularIconProgress({Key? key, required Widget icon, Color progressColor = Colors.red, Color backgroundColor = Colors.white, double size = 100.0, double strokeWidth = 4.0, Duration duration = const Duration(seconds: 2)})
const

Properties

backgroundColor Color
The background color of the circle
final
duration Duration
Animation duration for one complete rotation
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget
The icon to display in the center
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
progressColor Color
The color of the progress arc
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
The size of the entire component
final
strokeWidth double
The width of the progress arc
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CircularIconProgress>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited