OnboardingConfig class
Constructors
- OnboardingConfig({Color? scaffoldBackgroundColor, ScrollBehavior? scrollBehavior, TextStyle? titleStyle, TextStyle? subtitleStyle, TextStyle? termsStyle, Color? buttonColor, Color? buttonTextColor, double? buttonBorderRadius, Color? checkboxActiveColor, Color? checkboxCheckColor, double imageWidth = 200, double imageHeight = 200, BoxFit imageFit = BoxFit.contain, double imageBorderRadius = 12, Color? progressBarColor, Color? progressBarBackgroundColor, IconData? progressBarIcon, TextStyle? progressTextStyle})
-
const
- OnboardingConfig.defaultConfig()
-
factory
Properties
-
final
-
final
-
final
- checkboxActiveColor → Color?
-
final
- checkboxCheckColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageBorderRadius → double
-
final
- imageFit → BoxFit
-
final
- imageHeight → double
-
final
- imageWidth → double
-
final
- progressBarBackgroundColor → Color?
-
final
- progressBarColor → Color?
-
final
- progressBarIcon → IconData?
-
final
- progressTextStyle → TextStyle?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaffoldBackgroundColor → Color?
-
final
- scrollBehavior → ScrollBehavior?
-
final
- subtitleStyle → TextStyle?
-
final
- termsStyle → TextStyle?
-
final
- titleStyle → TextStyle?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited