FaceVerificationException class
Exception thrown when face verification fails
This can occur when:
- Liveness check fails
- Face matching fails
- Camera permission is denied
- User cancels the verification
- Network error during face API call
- Inheritance
-
- Object
- GetVerifiedException
- FaceVerificationException
Constructors
- FaceVerificationException(String message, {String? code, dynamic originalError, StackTrace? stackTrace})
-
const
Properties
- code → String?
-
Optional error code for programmatic error handling
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable error message
finalinherited
- originalError → dynamic
-
Original error that caused this exception (if any)
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
Stack trace from the original error (if available)
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited