GetVerifiedException class
Base exception class for all Get Verified SDK exceptions
All custom exceptions in the SDK extend this class to provide consistent error handling and debugging information.
- Implemented types
- Implementers
Constructors
- GetVerifiedException(String message, {String? code, dynamic originalError, StackTrace? stackTrace})
-
const
Properties
- code → String?
-
Optional error code for programmatic error handling
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable error message
final
- originalError → dynamic
-
Original error that caused this exception (if any)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
Stack trace from the original error (if available)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited