GetVerifiedConfig class

Main configuration class for the Get Verified SDK

This class consolidates all configuration options into a single, easy-to-use structure. It provides a clear hierarchy of settings and makes it easier to discover all available options.

Example:

final config = GetVerifiedConfig(
  documentReader: DocumentReaderConfig()
    .withColorTheme(ColorThemeConfig(primaryColor: '#4CAF50')),
  faceSDK: FaceSDKConfig()
    .withColors(FaceColorsConfig(
      cameraScreenStrokeActive: Colors.green,
    )),
  screens: ScreensConfig(
    onboarding: OnboardingConfig(buttonColor: Colors.green),
  ),
);

Constructors

GetVerifiedConfig({DocumentReaderConfig? documentReader, FaceSDKConfig? faceSDK, ScreensConfig? screens, ByteData? license, String? faceApiUrl, String? documentReaderUrl, Future<bool> onReprocess(String docTransactionId, String? faceLivenessTransactionId)?})
const
GetVerifiedConfig.minimal({required ByteData license, required String faceApiUrl, required String documentReaderUrl, Future<bool> onReprocess(String docTransactionId, String? faceLivenessTransactionId)?})
Creates a minimal configuration for quick testing
factory
GetVerifiedConfig.standard({required ByteData license, required String faceApiUrl, required String documentReaderUrl, ScreensConfig? screens, Future<bool> onReprocess(String docTransactionId, String? faceLivenessTransactionId)?})
Creates a standard configuration for production use
factory

Properties

documentReader DocumentReaderConfig?
Configuration for the document reader SDK
final
documentReaderUrl String?
Required URL for document reader API
final
faceApiUrl String?
Required URL for face verification API
final
faceSDK FaceSDKConfig?
Configuration for the face verification SDK
final
hashCode int
The hash code for this object.
no setterinherited
license ByteData?
Required license data for Regula SDK
final
onReprocess Future<bool> Function(String docTransactionId, String? faceLivenessTransactionId)?
Optional callback for reprocessing transactions. Return true if successful (to proceed), false otherwise.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screens ScreensConfig?
Configuration for all UI screens
final

Methods

copyWith({DocumentReaderConfig? documentReader, FaceSDKConfig? faceSDK, ScreensConfig? screens, ByteData? license, String? faceApiUrl, String? documentReaderUrl, Future<bool> onReprocess(String docTransactionId, String? faceLivenessTransactionId)?}) GetVerifiedConfig
Creates a copy with optional parameter overrides
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate() → void
Validates the configuration

Operators

operator ==(Object other) bool
The equality operator.
inherited