DocumentReaderConfig class
Main entry point for Document Reader SDK configuration This class provides a fluent API to configure all customization options
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
) → Future< void> - Apply all configurations to the Document Reader SDK
-
applyRuntime(
) → Future< void> - Apply changes in runtime (for Android)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → Future< void> - Reset all configurations to defaults
-
toString(
) → String -
A string representation of this object.
inherited
-
withBackground(
BackgroundConfig config) → DocumentReaderConfig - Configure background
-
withCameraFrame(
CameraFrameConfig config) → DocumentReaderConfig - Configure camera frame
-
withColorTheme(
ColorThemeConfig config) → DocumentReaderConfig - Configure color theme
-
withFunctionality(
FunctionalityConfig config) → DocumentReaderConfig - Configure functionality
-
withIndicators(
IndicatorsConfig config) → DocumentReaderConfig - Configure indicators
-
withInstructions(
InstructionsConfig config) → DocumentReaderConfig - Configure instructions
-
withLiveness(
LivenessCustomConfig config) → DocumentReaderConfig - Configure liveness check
-
withMessages(
MessagesConfig config) → DocumentReaderConfig - Configure messages
-
withMultipage(
MultipageConfig config) → DocumentReaderConfig - Configure multipage processing
-
withProcessParams(
ProcessParamsConfig config) → DocumentReaderConfig - Configure process parameters
-
withToolbar(
ToolbarConfig config) → DocumentReaderConfig - Configure toolbar
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited