FunctionalityConfig class
Constructors
- FunctionalityConfig({CameraMode? cameraMode, CameraPosition? cameraPosition, double? zoomFactor, bool zoomEnabled = true, CaptureMode? captureMode, DocReaderOrientation? orientation, bool skipFocusingFrames = true, double? exposure, bool recordScanningProcess = false, bool isVibration = true, bool displayMetadata = false, int? forcedDocType, bool useAuthenticator = true})
Properties
- cameraMode → CameraMode?
-
final
- cameraPosition → CameraPosition?
-
final
- captureMode → CaptureMode?
-
final
- displayMetadata → bool
-
final
- exposure → double?
-
final
- forcedDocType → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isVibration → bool
-
final
- orientation → DocReaderOrientation?
-
final
- recordScanningProcess → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipFocusingFrames → bool
-
final
- useAuthenticator → bool
-
final
- zoomEnabled → bool
-
final
- zoomFactor → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited