LivenessCustomConfig class

Constructors

LivenessCustomConfig({bool motionControl = false, bool showCaptureButton = true, int? captureButtonDelayFromDetect, int? captureButtonDelayFromStart})

Properties

captureButtonDelayFromDetect int?
final
captureButtonDelayFromStart int?
final
hashCode int
The hash code for this object.
no setterinherited
motionControl bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCaptureButton bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited