ToolbarConfig class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- show → bool
-
final
- showCameraSwitchButton → bool
-
final
- showCaptureButton → bool
-
final
- showChangeFrameButton → bool
-
final
- showCloseButton → bool
-
final
- showTorchButton → bool
-
final
- size → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited