DocReaderSdkInitializer class
Constructors
Properties
-
databasePrepProgress
↔ ValueNotifier<
double> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDatabasePrepared → bool
-
no setter
- isPreparingDatabase → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
initialize(
{required ByteData license, required String webServiceUrl}) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prepareDatabaseAndInitialize(
{required ByteData license, required String webServiceUrl}) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
backendInitialize(
String webServiceUrl) → void -
deinitialize(
) → void