FaceFontsConfig class
Configuration for Face SDK font customization
Constructors
- FaceFontsConfig({String? fontFamily, int? onboardingScreenMessageLabelsSize, int? onboardingScreenStartButtonSize, int? onboardingScreenTitleLabelSize, int? onboardingScreenSubtitleLabelSize, int? cameraScreenHintLabelSize, int? processingScreenLabelSize, int? retryScreenTitleLabelSize, int? retryScreenSubtitleLabelSize, int? retryScreenHintLabelsSize, int? retryScreenRetryButtonSize})
-
const
Properties
- cameraScreenHintLabelSize → int?
-
final
- fontFamily → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onboardingScreenMessageLabelsSize → int?
-
final
- onboardingScreenStartButtonSize → int?
-
final
- onboardingScreenSubtitleLabelSize → int?
-
final
- onboardingScreenTitleLabelSize → int?
-
final
- processingScreenLabelSize → int?
-
final
- retryScreenHintLabelsSize → int?
-
final
- retryScreenRetryButtonSize → int?
-
final
- retryScreenSubtitleLabelSize → int?
-
final
- retryScreenTitleLabelSize → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited