GetVerifiedSolution class
Constructors
Properties
- docReaderSdkSteps → DocReaderSdkSteps
-
final
- faceSdkSteps → FaceSdkSteps
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handleCompletion(
DocReaderAction action, Results? result, DocReaderException? error) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startProcess(
{required String faceApiUrl, String mode = "match", DocumentReaderConfig? documentReaderConfig, FaceSDKConfig? faceSDKConfig, dynamic onDocumentFetched(ScanResult)?, dynamic onFaceMismatch()?, dynamic onVerificationSuccess(ScanResult)?, dynamic onError(GetVerifiedException)?}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited