GetVerifiedUploadSolution class
Constructors
Properties
- docReaderSdkSteps → DocReaderSdkSteps
-
final
- faceSdkSteps → FaceSdkSteps
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handleCompletionWithUpload(
DocReaderAction action, Results? result, DocReaderException? error) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startProcessWithUpload(
{required String faceApiUrl, required XFile image, String mode = "match", DocumentReaderConfig? documentReaderConfig, dynamic onError(GetVerifiedException)?, dynamic onTransactionIds(String? faceTransactionId, String? docTransactionId)?}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited