FormConfig class

Constructors

FormConfig({required NavigationType navigationType, required List<FieldConfig> fields, String title = "Create An Account", String subtitle = "Join now for free and be part of United's global fan community to enjoy exclusive perks & rewards", String buttonText = "Create Account", String? logoPath, bool showTerms = true})

Properties

buttonText String
final
fields List<FieldConfig>
final
hashCode int
The hash code for this object.
no setterinherited
logoPath String?
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showTerms bool
final
subtitle String
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited