FormConfig class
Constructors
-
FormConfig({required List<
FieldConfig> fields, String title = "Create An Account", String subtitle = "Join now for free and be part of United's global fan community to enjoy exclusive perks & rewards", String buttonText = "Create Account", String? logoPath, bool showTerms = true})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited