FormConfig constructor
FormConfig({})
Implementation
FormConfig({
required this.navigationType,
required this.fields,
this.title = "Create An Account",
this.subtitle =
"Join now for free and be part of United's global fan community to enjoy exclusive perks & rewards",
this.buttonText = "Create Account",
this.logoPath,
this.showTerms = true,
});