UIConfig class
Constructors
- UIConfig({Color? scaffoldBackgroundColor, Color? appBarBackgroundColor, Color? sectionTitleColor, Color? subtitleColor, TextStyle? titleStyle, TextStyle? subtitleStyle, ButtonStyle? submitButtonStyle, TextStyle? submitButtonTextStyle, InputDecorationTheme? inputDecorationTheme})
-
const
Properties
- appBarBackgroundColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputDecorationTheme → InputDecorationTheme?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaffoldBackgroundColor → Color?
-
final
- sectionTitleColor → Color?
-
final
- submitButtonStyle → ButtonStyle?
-
final
- submitButtonTextStyle → TextStyle?
-
final
- subtitleColor → Color?
-
final
- subtitleStyle → TextStyle?
-
final
- titleStyle → TextStyle?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited